#
# spec file for package qdox
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qdox
Version:        2.1.0
Release:        1.4
Summary:        Tool to extract class/interface/method definitions from sources
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/paul-hammant/qdox
Source0:        https://repo1.maven.org/maven2/com/thoughtworks/qdox/qdox/%{version}/%{name}-%{version}-project.tar.bz2
Source1:        qdox-build.xml
Patch0:         Port-to-JFlex-1.7.0.patch
BuildRequires:  ant
BuildRequires:  byaccj
BuildRequires:  fdupes
BuildRequires:  java-cup-bootstrap
BuildRequires:  java-devel
BuildRequires:  javapackages-local >= 6
BuildRequires:  jflex-bootstrap
BuildArch:      noarch

%description
QDox is a parser for extracting class/interface/method definitions
from source files complete with JavaDoc @tags. It is designed to be
used by active code generators or documentation tools.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
API docs for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml
%patch -P 0 -p1
find -name *.jar -delete
find -name *.class -delete
rm -rf bootstrap
# We don't need these plugins
%pom_remove_plugin :animal-sniffer-maven-plugin
%pom_remove_plugin :maven-assembly-plugin
%pom_remove_plugin :maven-failsafe-plugin
%pom_remove_plugin :maven-invoker-plugin
%pom_remove_plugin :jflex-maven-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :exec-maven-plugin

%pom_remove_parent .

%build
# Generate scanners (upstream does this with maven-jflex-plugin)
jflex -d src/main/java/com/thoughtworks/qdox/parser/impl src/grammar/lexer.flex
jflex -d src/main/java/com/thoughtworks/qdox/parser/impl src/grammar/commentlexer.flex

# Generate parsers (upstream does this with exec-maven-plugin)
(cd ./src/main/java/com/thoughtworks/qdox/parser/impl
 byaccj -v -Jnorun -Jnoconstruct -Jclass=DefaultJavaCommentParser -Jpackage=com.thoughtworks.qdox.parser.impl ../../../../../../../grammar/commentparser.y
 byaccj -v -Jnorun -Jnoconstruct -Jclass=Parser -Jimplements=CommentHandler -Jsemantic=Value -Jpackage=com.thoughtworks.qdox.parser.impl -Jstack=500 ../../../../../../../grammar/parser.y
)

%ant -Dproject.version=%{version} jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar -a qdox:qdox
# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -aL target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt
%doc README.md

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE.txt

%changelog
* Wed Apr 10 2024 Fridrich Strba <fstrba@suse.com>
- Update to version 2.1.
  * Changes:
    + clarify getComment() javadoc with regards to Standard doclet
    inline and
    + Require Java 8 to run QDox (#171)
    + Replace hamcrest with assertj (#173)
    + Upgrade to Mockito 4.11.0 with some small required code
    changes (#174)
    + implement JavaWildcardType.getLowerBounds and
    JavaWildcardType.getUpperBounds
    + Fix unittests
    + maven-gpg-plugin is not a managed plugin in oss-parent, move
    it to build.plugins
    + Fix the bug that does not allow the use of permits as field
    names (#202)
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Sep 21 2023 Fridrich Strba <fstrba@suse.com>
- Build with java source/target levels 8
* Fri May 12 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 2.0.3:
  * Changes:
    + Update documentation #41
    + interface should be ignored as modifier #115
    + add byaccj 1.15 binaries for Mac OS on aarch64 (#109)
    + Correctly resolve types with SourceFolderLibrary (#105)
    + #99 Seems QDox 2.0.1 has issue parsing parameters names named
    "recordList" and "record"
* Sat Mar 12 2022 Fridrich Strba <fstrba@suse.com>
- Add Automatic-Module-Name to the manifest
- Added patch:
  * Port-to-JFlex-1.7.0.patch
    + Don't use deprecated inputstreamctor option
* Thu Jan 13 2022 Fridrich Strba <fstrba@suse.com>
- Update to version 2.0.1:
  * Changes:
    + Support Lambda Expression
    + Add SEALED / NON_SEALED tokens
    + #75 CodeBlock for Annotation with FieldReference should prefix
  field with canonical name
    + Add UnqualifiedClassInstanceCreationExpression
    + updating jflex-maven-plugin to 1.8.2
    + Add reference to grammar documentation and hints to transform
  it
    + Support Text Blocks
    + Support Sealed Classes
    + #67 Support records
    + #76 test with an @@ in comment
    + #64 Get interface via javaProjectBuilder.getClassByName
- Generate ant build file from maven pom and build using ant
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.0.0:
  * No upstream changelog provided
* Mon Apr  8 2019 Fridrich Strba <fstrba@suse.com>
- Do not depend on the parent pom, since we are not building
  using Maven.
* Tue Jan 15 2019 Fridrich Strba <fstrba@suse.com>
- BuildRequires: java-cup-bootstrap and jflex-bootstrap to avoid
  build cycle (bsc#1121958)
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary, and trim bias from descriptions.
* Tue Jan  1 2019 Fridrich Strba <fstrba@suse.com>
- Update to version 2.0-M9
  * Changed API to use Collections and Lists instead of Arrays
  * No upstream changelog provided :/
* Mon Oct 29 2018 Fridrich Strba <fstrba@suse.com>
- Install and package the maven artifact
* Thu Apr  5 2018 fstrba@suse.com
- Build with java source and target version 6 in order to produce
  bytecode understood by all supported java versions
* Fri Jun  9 2017 tchvatal@suse.com
- Remove maven conditionals
- Drop javadoc to bootstrap
* Thu Aug 28 2014 coolo@suse.com
- rename the conditional to junit_test and switch the default,
  bootstrapping factory is more important than a single test
* Tue Aug 12 2014 lnussel@suse.de
- introduce %%with java_bootstrap to allow bootstrapping without junit
* Thu May 15 2014 darin@darins.net
- Added xz build requirement for sles
- no bytecode check on sles
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri Nov 30 2012 cobexer@gmail.com
- update to 1.12.1
  * bugfix release, see
  * http://jira.codehaus.org/browse/QDOX/fixforversion/18944
* Wed Nov 28 2012 mvyskocil@suse.com
- require saxon9 for build
* Wed Oct 24 2012 mvyskocil@suse.com
- update to 1.12
  * needed for the fop 1.1 update
  * mostly bugfix release, see
  * http://qdox.codehaus.org/changes-report.html
- disabled tests as they tends to randomly fails
* Tue May  5 2009 mvyskocil@suse.cz
- Initial build in SUSE. Version 1.6.1 from jpp 5.0
